@@ -2,6 +2,7 @@
 
 namespace Prophecy\PhpUnit\Tests;
 
+use PHPUnit\TextUI\Application;
 use PHPUnit\TextUI\Command;
 
 require_once __DIR__ . '/xdebug_filter.php';
@@ -14,5 +15,11 @@ function runTest(string $fixtureName): void
         throw new \InvalidArgumentException('Unable to find test fixture at path ' . $filename);
     }
 
-    (new Command())->run(['phpunit', $filename], false);
+    if (class_exists(Command::class)) {
+        // PHPUnit 9.x
+        (new Command())->run(['phpunit', $filename, '--verbose', '--no-configuration'], false);
+    } else {
+        // PHPUnit 10.x
+        (new Application())->run(['phpunit', $filename, '--no-configuration']);
+    }
 }
